package jalview.schemes;

import static org.testng.Assert.assertNull;
import static org.testng.Assert.assertSame;
import static org.testng.Assert.assertTrue;

import jalview.datamodel.Alignment;
import jalview.datamodel.AlignmentI;
import jalview.datamodel.Sequence;
import jalview.datamodel.SequenceI;

import org.testng.annotations.Test;

public class JalviewColourSchemeTest
{
  @Test
  public void testForName()
  {
    assertSame(JalviewColourScheme.Clustal,
            JalviewColourScheme.forName("Clustal"));
    assertSame(JalviewColourScheme.Clustal,
            JalviewColourScheme.forName("CLUSTAL"));
    assertSame(JalviewColourScheme.Blosum62,
            JalviewColourScheme.forName("Blosum62"));
    assertSame(JalviewColourScheme.PID,
            JalviewColourScheme.forName("% Identity"));
    assertSame(JalviewColourScheme.Hydrophobic,
            JalviewColourScheme.forName("Hydrophobic"));
    assertSame(JalviewColourScheme.Zappo,
            JalviewColourScheme.forName("Zappo"));
    assertSame(JalviewColourScheme.Taylor,
            JalviewColourScheme.forName("Taylor"));
    assertSame(JalviewColourScheme.Helix,
            JalviewColourScheme.forName("Helix Propensity"));
    assertSame(JalviewColourScheme.Strand,
            JalviewColourScheme.forName("Strand Propensity"));
    assertSame(JalviewColourScheme.Turn,
            JalviewColourScheme.forName("Turn Propensity"));
    assertSame(JalviewColourScheme.Buried,
            JalviewColourScheme.forName("Buried Index"));
    assertSame(JalviewColourScheme.Nucleotide,
            JalviewColourScheme.forName("Nucleotide"));
    assertSame(JalviewColourScheme.PurinePyrimidine,
            JalviewColourScheme.forName("Purine/Pyrimidine"));
    assertSame(JalviewColourScheme.TCoffee,
            JalviewColourScheme.forName("T-Coffee Scores"));
    assertSame(JalviewColourScheme.RNAHelices,
            JalviewColourScheme.forName("RNA Helices"));
    // assertSame(JalviewColourScheme.RNAInteraction,
    // JalviewColourScheme.forName("RNA Interaction type"));
    assertSame(JalviewColourScheme.UserDefined,
            JalviewColourScheme.forName("User Defined"));

    assertNull(JalviewColourScheme.forName("PID"));
    assertNull(JalviewColourScheme.forName(""));
    assertNull(JalviewColourScheme.forName(null));
  }

  @Test
  public void testGetColourScheme()
  {
    SequenceI seq = new Sequence("Seq1", "abcd");
    AlignmentI al = new Alignment(new SequenceI[] { seq });
    assertTrue(JalviewColourScheme.Clustal.getColourScheme(al) instanceof ClustalxColourScheme);
    assertTrue(JalviewColourScheme.Blosum62.getColourScheme(al) instanceof Blosum62ColourScheme);
    assertTrue(JalviewColourScheme.PID.getColourScheme(al) instanceof PIDColourScheme);
    assertTrue(JalviewColourScheme.Hydrophobic.getColourScheme(al) instanceof HydrophobicColourScheme);
    assertTrue(JalviewColourScheme.Zappo.getColourScheme(al) instanceof ZappoColourScheme);
    assertTrue(JalviewColourScheme.Taylor.getColourScheme(al) instanceof TaylorColourScheme);
    assertTrue(JalviewColourScheme.Helix.getColourScheme(al) instanceof HelixColourScheme);
    assertTrue(JalviewColourScheme.Strand.getColourScheme(al) instanceof StrandColourScheme);
    assertTrue(JalviewColourScheme.Turn.getColourScheme(al) instanceof TurnColourScheme);
    assertTrue(JalviewColourScheme.Buried.getColourScheme(al) instanceof BuriedColourScheme);
    assertTrue(JalviewColourScheme.Nucleotide.getColourScheme(al) instanceof NucleotideColourScheme);
    assertTrue(JalviewColourScheme.PurinePyrimidine.getColourScheme(al) instanceof PurinePyrimidineColourScheme);
    assertTrue(JalviewColourScheme.TCoffee.getColourScheme(al) instanceof TCoffeeColourScheme);
    assertTrue(JalviewColourScheme.RNAHelices.getColourScheme(al) instanceof RNAHelicesColour);
    // assertTrue(JalviewColourScheme.RNAInteraction.getColourScheme(al)
    // instanceof RNAInteractionColourScheme);
    assertTrue(JalviewColourScheme.UserDefined.getColourScheme(al) instanceof UserColourScheme);
  }
}
